@@ -8,7 +8,7 @@ from torch_geometric.utils.convert import from_networkx
 from bpemb import BPEmb
 from sentence_transformers import SentenceTransformer
 from graphmanagerlib.Graph import Grapher
-from graphmanagerlib.JsonManager import ConvertJsonToDocumentsObjects
+from graphmanagerlib.JsonManager import ConvertJsonToDocumentsObjects, GetJsonFromFile
 
 bpemb_en = BPEmb(lang="en", dim=100)
 sent_model = SentenceTransformer('distilbert-base-nli-stsb-mean-tokens')
@@ -98,9 +98,10 @@ def makeIndividualData(file):
     print(f'File {file.index} --> Success')
     return individual_data
 
-def getDataForUniquePrediction(json,save_fd):
+def getDataForUniquePrediction(jsonPath,save_fd):
     test_list_of_graphs = []
-    jsonAsDoc = ConvertJsonToDocumentsObjects(json)[0]
+    jsonAsObject = GetJsonFromFile(jsonPath)
+    jsonAsDoc = ConvertJsonToDocumentsObjects(jsonAsObject)[0]
     individual_data = makeIndividualData(jsonAsDoc)
     test_list_of_graphs.append(individual_data)
     test_data = torch_geometric.data.Batch.from_data_list(test_list_of_graphs)
